#
# spec file for package dunst
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_userunitdir:%define _userunitdir %{_prefix}/lib/systemd/user}
Name:           dunst
Version:        1.3.2
Release:        lp152.3.7
Summary:        A customizable notification daemon
License:        BSD-3-Clause
Group:          System/GUI/Other
URL:            https://dunst-project.org
Source:         https://github.com/dunst-project/dunst/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         makefile.patch
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libxdg-basedir)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xrandr)
BuildRequires:  pkgconfig(xscrnsaver)

%description
Dunst is a customizable replacement for the notification daemons
provided by most desktop environments.

%prep
%setup -q
%patch0 -p1

%build
CFLAGS="%{optflags}" make %{?_smp_mflags}

%install
%make_install PREFIX=%{_prefix}

sed -i -e 's/Exec.*/Exec=\/usr\/bin\/dunst/' %{buildroot}/%{_datadir}/dbus-1/services/org.knopwob.dunst.service
sed -i -e 's/ExecStart.*/ExecStart=\/usr\/bin\/dunst/' %{buildroot}/%{_userunitdir}/dunst.service

%files
%doc CHANGELOG.md README.md
%license LICENSE
%{_bindir}/dunst
%{_datadir}/dbus-1/services/org.knopwob.dunst.service
%{_userunitdir}/dunst.service
%{_datadir}/dunst
%{_mandir}/man1/dunst.1%{?ext_man}

%changelog
* Sun May  6 2018 avindra@opensuse.org
- update to version 1.3.2
  * Fix crash when loading invalid or corrupt icon file
- minor cleanup with spec-cleaner
- use %%make_install macro
* Tue Feb 20 2018 mimi.vx@gmail.com
- add makefile.patch to fix service installation
* Sun Feb 11 2018 jengelh@inai.de
- Trim filler wording from description.
* Wed Feb  7 2018 arun@gmx.de
- specfile:
  * updated copyright year
  * changed dependency gdk-2.0 to gdk-pixbuf-2.0
- update to version 1.3.1
  * Race condition resulting in the service files being empty (#488)
- changes from version 1.3.0:
  * Added
    + ellipsize option to control how long lines should be ellipsized
    when word_wrap is set to false (#374)
    + A beginning tilde of a path is now expanded to the home of the
    current user (#351)
    + The image-path hint is now respected, as GApplications send
    their icon only via this link (#447)
    + The (legacy) image_data hint is now respected (#353)
    + If dunst can't acquire the DBus name, dunst prints the PID of
    the process holding the name (#458 #460)
    + Increased accuracy of timeouts by using microseconds internally
    (#379 #291)
    + Support for specifying timeout values in milliseconds, minutes,
    hours, or days. (#379)
    + Support for HTML img tags (via context menu) (#428)
  * Fixed
    + new_icon rule being ignored on notifications that had a raw icon
    (#423)
    + Format strings being replaced recursively in some cases (#322
    [#365])
    + DBus related memory leaks (#397)
    + Crash on X11 servers with RandR support less than 1.5. (#413
    [#364])
    + Silently reading the default config file, if -conf did not
    specify a valid file (#452)
    + Notification window flickering when a notification is replaced
    (#320 #415)
    + Inaccurate timeout in some cases (#291 #379)
  * Changed
    + Transient hints are now handled (#343 #310) An additional rule
    option (match_transient and set_transient) is added to
    optionally reset the transient setting
    + HTML links are now referred to by their text in the context menu
    rather than numbers (#428)
    + icon_folders setting renamed to icon_path (#170)
    + config.def.h and config.h got merged (#371)
    + The dependency on GTK3+ has been removed. Instead of GTK3+,
    dunst now requires gdk-pixbuf which had been a transient
    dependency before. (#334 #376)
    + The _GNU_SOURCE macros had been removed to make dunst portable
    to nonGNU systems (#403)
    + Internal refactorings of the notification queue handling. (#411)
    + Dunst does now install the systemd and dbus service files into
    their proper location given by pkg-config. Use
    SERVICEDIR_(DBUS|SYSTEMD) params to overwrite them. (#463)
* Sat Jul 22 2017 mimi.vx@gmail.com
- update to 1.2.0
- dropped dunst_bad_free.patch
  * always_run_script option to run script even if a notification is suppressed
  * Support for more icon file types
  * Support for raw icons
  * hide_duplicate_count option to hide the number of duplicate notifications
  * Support for per-urgency frame colours
  * markup setting for more fine-grained control over how markup is handled
  * history_ignore rule action to exclude a notification from being
  added to the history
  * Support for setting the dpi value dunst will use for font rendering
  via the Xft.dpi X resource
  * Experimental support for per-monitor dpi calculation
  * max_icon_size option to scale down icons if they exceed a certain size
  * Middle click on notifications can be used to trigger actions
  * Systemd service file, installed by default
  * %%n format flag for getting progress value without any extra characters
  * Text and icons are now centred vertically
  * Notifications aren’t considered duplicate if urgency or icons differ
  * The maximum length of a notification is limited to 5000 characters
  * The frame width and color settings were moved to the global section
  as frame_width and frame_color respectively
  * Dropped Xinerama in favour of RandR, Xinerama can be enabled with
  the -force_xinerama option if needed
  * allow_markup is deprecated with markup as its replacement
  * The urgency specific command line flags have been deprecated with
  no replacement, respond to issue #328 on the bug tracker
  if you depend on them
  * Infinite loop if there are 2 configuration file sections with the same name
  * URLs with dashes and underscores in them are now parsed properly
  * Many memory leaks
  * Category based rules were applied without actually matching
  * dmenu command not parsing quoted arguments correctly
  * Icon alignment with dynamic width
  * Issue when loading configuration files with very long lines
  * ‘\n’ is no longer expanded to a newline inside notification text
  * Notification window wasn’t redrawn if obscured on systems without a compositor
  * ignore_newline now works regardless of the markup setting
  * dmenu process being left as a zombie if no option was selected
  * Crash when opening urls parsed from <a href=""> tags
* Sat Jan 21 2017 mimi.vx@gmail.com
- removed unneded deps
- fixed bad free and memory leak by dunst_bad_free.patch
* Thu Jun 18 2015 mimi.vx@gmail.com
- update to 1.1.0
  * bugfixes ( memmory leak on Spotify )
  * icons
- spec-cleaned
* Wed May 29 2013 fcastelli@suse.com
- created initial package (1.0.0)
